"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.fetchRepos = void 0;
const core_1 = require("../core");
exports.fetchRepos = async (owner) => {
    const res = await core_1.http.request(`https://api.github.com/users/${owner}/repos`, {
        searchParams: {
            client_id: '0cb723972877555ffb54',
            client_secret: 'ad0638a75ee90bb86c8b551f5f42f3a044725f38',
            per_page: 100,
            sort: 'updated'
        },
        timeout: 5 * 1000
    });
    return res.body;
};
const command = {
    name: 'list',
    usage: 'list [owner]',
    description: 'list available official templates.',
    alias: 'ls',
    options: {
        json: {
            type: 'boolean',
            alias: 'j',
            default: false,
            description: 'json mode templates outputs'
        },
        short: {
            type: 'boolean',
            alias: 's',
            default: false,
            description: 'short mode templates outputs'
        }
    },
    action: async ({ primary: owner = 'zce-templates', options }) => {
        const { json, short } = options;
        const spinner = core_1.logger.spin('Loading available list from remote...');
        spinner.start();
        try {
            const repos = await exports.fetchRepos(owner);
            spinner.stop();
            const isOfficial = owner === 'zce-templates';
            if (json) {
                return core_1.logger.info(JSON.stringify(repos.map(i => ({
                    name: i.name,
                    owner: i.owner.login,
                    description: i.description,
                    updated: i.updated_at
                }))));
            }
            if (short) {
                return repos.forEach(item => core_1.logger.info(`→ ${isOfficial ? item.name : item.full_name}`));
            }
            if (!repos.length) {
                return core_1.logger.info('😞  No available templates.');
            }
            core_1.logger.info(`👇  Available ${isOfficial ? 'official' : owner}'s templates:`);
            core_1.logger.newline();
            const infos = repos.map(i => [
                core_1.logger.color `{yellow →} {blue ${isOfficial ? i.name : i.full_name}}`,
                i.description
            ]);
            core_1.logger.table(infos, 32, 2);
        }
        catch (e) {
            spinner.fail(core_1.logger.color `😞  Failed to load list from remote: {red ${e.message}}.`);
        }
    }
};
exports.default = command;
