"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.invokeHelp = exports.outputHelp = void 0;
const helpers_1 = require("../helpers");
const loader_1 = require("../loader");
const outputCommands = () => {
    const cmds = [...new Set(Object.values(loader_1.commands))].filter(i => !i.hidden && i.name !== 'default');
    if (cmds.length) {
        helpers_1.logger.newline();
        helpers_1.logger.info('Commands:');
        const infos = cmds.map(i => [
            `${i.name}${i.alias ? ` (${i.alias})` : ''}`,
            i.description || '-'
        ]);
        helpers_1.logger.table(infos, 10, 2);
    }
};
const outputOptions = (options) => {
    helpers_1.logger.newline();
    helpers_1.logger.info('Options:');
    const optKey = (k) => `${k.length === 1 ? '-' : '--'}${k}`;
    const infos = Object.keys(options).map(k => {
        const opt = options[k];
        const keys = [`--${k}`];
        let value = '-';
        if (typeof opt === 'object') {
            if (Array.isArray(opt.alias)) {
                keys.push(...opt.alias.map(optKey));
            }
            else if (typeof opt.alias === 'string') {
                keys.push(optKey(opt.alias));
            }
            value = opt.description || '-';
        }
        return [keys.join(', '), value];
    });
    helpers_1.logger.table(infos, 10, 2);
};
const outputTips = (title, tips, bin) => {
    helpers_1.logger.newline();
    helpers_1.logger.info(title);
    if (typeof tips !== 'string') {
        tips = tips.join('\n');
    }
    helpers_1.logger.info(helpers_1.logger.indent(tips.replace(/\[bin\]/g, bin)));
};
exports.outputHelp = (cmd, ctx) => {
    if (cmd.description) {
        helpers_1.logger.info(cmd.description);
        helpers_1.logger.newline();
    }
    helpers_1.logger.info('Usage:');
    helpers_1.logger.info(helpers_1.logger.indent(`$ ${ctx.bin} ${cmd.usage || `${cmd.name} [options]`}`));
    if (cmd.name === 'default') {
        outputCommands();
    }
    if (cmd.options) {
        outputOptions(cmd.options);
    }
    if (cmd.examples) {
        outputTips('Examples:', cmd.examples, ctx.bin);
    }
    if (cmd.suggestions) {
        outputTips('Suggestions:', cmd.suggestions, ctx.bin);
    }
};
exports.invokeHelp = async (cmd, ctx) => {
    if (cmd.help) {
        if (typeof cmd.help === 'string') {
            helpers_1.logger.info(cmd.help);
        }
        else {
            await cmd.help(ctx);
        }
    }
    else {
        exports.outputHelp(cmd, ctx);
    }
    process.exit();
};
const command = {
    name: 'help',
    usage: 'help <command>',
    description: 'output usage information.',
    action: async (ctx) => {
        const cmd = await loader_1.load(ctx.primary || 'default');
        return await exports.invokeHelp(cmd, ctx);
    }
};
exports.default = command;
