"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.extract = exports.untildify = exports.tildify = exports.minimatch = exports.glob = exports.remove = exports.mkdir = exports.isEmpty = exports.isDirectory = exports.isFile = exports.exists = exports.getDataPath = exports.getTempPath = exports.write = exports.read = void 0;
const os_1 = __importDefault(require("os"));
const extract_zip_1 = __importDefault(require("extract-zip"));
const fs_1 = require("fs");
const path_1 = __importDefault(require("path"));
const glob_1 = require("glob");
const minimatch_1 = require("minimatch");
const { name } = require('../../../package.json');
const identify = process.env.NODE_ENV === 'test' ? `${name}-test` : name;
exports.read = async (input) => {
    return fs_1.promises.readFile(input);
};
exports.write = async (input, contents) => {
    const dirname = path_1.default.dirname(input);
    await exports.mkdir(dirname);
    return fs_1.promises.writeFile(input, contents);
};
exports.getTempPath = (...paths) => {
    return path_1.default.join(os_1.default.tmpdir(), identify, ...paths);
};
exports.getDataPath = (...paths) => {
    return path_1.default.join(os_1.default.homedir(), '.config', identify, ...paths);
};
exports.exists = async (input) => {
    try {
        const stat = await fs_1.promises.stat(input);
        if (stat.isDirectory()) {
            return 'dir';
        }
        else if (stat.isFile()) {
            return 'file';
        }
        else {
            return 'other';
        }
    }
    catch (err) {
        if (err.code !== 'ENOENT') {
            throw err;
        }
    }
    return false;
};
exports.isFile = async (input) => {
    const result = await exports.exists(input);
    return result === 'file';
};
exports.isDirectory = async (input) => {
    const result = await exports.exists(input);
    return result === 'dir';
};
exports.isEmpty = async (input) => {
    const files = await fs_1.promises.readdir(input);
    return !files.length;
};
exports.mkdir = async (input, options) => {
    await fs_1.promises.mkdir(input, { recursive: true, ...options });
};
exports.remove = async (input, options) => {
    await fs_1.promises.rmdir(input, { recursive: true, ...options });
};
exports.glob = async (pattern, options) => new Promise((resolve, reject) => {
    return new glob_1.Glob(pattern, options, (err, files) => {
        if (err)
            return reject(err);
        resolve(files);
    });
});
exports.minimatch = (input, pattern, options) => {
    const match = new minimatch_1.Minimatch(pattern, options);
    return match.match(input);
};
exports.tildify = (input) => {
    const home = os_1.default.homedir();
    input = path_1.default.normalize(input) + path_1.default.sep;
    if (input.indexOf(home) === 0) {
        input = input.replace(home + path_1.default.sep, `~${path_1.default.sep}`);
    }
    return input.slice(0, -1);
};
exports.untildify = (input) => {
    const home = os_1.default.homedir();
    return input.replace(/^~(?=$|\/|\\)/, home);
};
exports.extract = async (input, output, strip = 0) => {
    await extract_zip_1.default(input, {
        dir: output,
        onEntry: entry => {
            if (!strip)
                return;
            const items = entry.fileName.split(/\/|\\/);
            const start = Math.min(items.length, strip);
            entry.fileName = items.slice(start).join('/');
        }
    });
};
