"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.spin = exports.indent = exports.clear = exports.divider = exports.newline = exports.table = exports.debug = exports.error = exports.warn = exports.success = exports.info = exports.log = exports.color = void 0;
const readline_1 = __importDefault(require("readline"));
const chalk_1 = __importDefault(require("chalk"));
const redent_1 = __importDefault(require("redent"));
const ora_1 = __importDefault(require("ora"));
exports.color = new chalk_1.default.Instance({
    level: process.env.NODE_ENV === 'test' ? 0 : 3
});
exports.log = (...args) => {
    console.log(...args);
};
exports.info = (message, ...args) => {
    exports.log(exports.color.reset(message), ...args);
};
exports.success = (message, ...args) => {
    exports.log(exports.color.green(message), ...args);
};
exports.warn = (message, ...args) => {
    exports.log(exports.color.yellow(message), ...args);
};
exports.error = (message, ...args) => {
    exports.log(exports.color.red(message), ...args);
};
exports.debug = (message, title = 'DEBUG') => {
    exports.log(exports.color.magenta(`↓↓↓ --------------------[ ${title} ]-------------------- ↓↓↓`));
    exports.log(message);
    exports.log(exports.color.magenta(`↑↑↑ --------------------[ ${title} ]-------------------- ↑↑↑`));
};
exports.table = (infos, min = 10, indent = 0) => {
    if (!Array.isArray(infos)) {
        infos = Object.entries(infos);
    }
    min = Math.max(min, ...infos.map(i => i[0].length));
    let text = infos.map(i => `${i[0].padEnd(min)}  ${i[1]}`).join('\n');
    text = indent ? redent_1.default(text, indent) : text;
    exports.log(text);
};
exports.newline = () => {
    exports.log('');
};
exports.divider = () => {
    exports.log(exports.color.gray('-'.repeat(80)));
};
exports.clear = (title) => {
    if (!process.stdout.isTTY)
        return;
    exports.log('\n'.repeat(process.stdout.rows || 30));
    readline_1.default.cursorTo(process.stdout, 0, 0);
    readline_1.default.clearScreenDown(process.stdout);
    title && exports.log(title);
};
exports.indent = (input, size = 2) => {
    return redent_1.default(input, size);
};
exports.spin = (options = '') => {
    return ora_1.default(options).start();
};
