"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.load = exports.commands = exports.loadCommands = void 0;
const path_1 = require("path");
const fs_1 = require("fs");
exports.loadCommands = (dir) => {
    const commandDir = path_1.join(__dirname, dir);
    return fs_1.readdirSync(commandDir).reduce((cmds, item) => {
        try {
            const { default: mod } = require(path_1.join(commandDir, item));
            if (typeof mod === 'undefined' || typeof mod.name !== 'string' || typeof mod.action !== 'function')
                return cmds;
            const cmd = mod;
            if (cmd.options && !cmd.options.help) {
                cmd.options.help = {
                    type: 'boolean',
                    alias: 'h',
                    description: 'output command help info'
                };
            }
            cmds[cmd.name] = cmd;
            if (typeof cmd.alias === 'string') {
                cmds[cmd.alias] = cmd;
            }
            else if (cmd.alias) {
                cmd.alias.forEach(a => {
                    cmds[a] = cmd;
                });
            }
        }
        catch (_a) { }
        return cmds;
    }, {});
};
exports.commands = {
    ...exports.loadCommands('./commands'),
    ...exports.loadCommands('../commands')
};
exports.load = async (name) => {
    if (name && exports.commands[name]) {
        return exports.commands[name];
    }
    return exports.commands.unknown;
};
